@@ -23,6 +23,7 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <sys/types.h>
+#include <gio/gio.h>
 
 #include <libanjuta/anjuta-preferences.h>
 
@@ -56,7 +57,7 @@ gboolean anjuta_util_dialog_boolean_question (GtkWindow *parent,
 gboolean anjuta_util_dialog_input (GtkWindow *parent, const gchar *label,
 								   const gchar *default_value, gchar **value);
 
-gboolean anjuta_util_prog_is_installed (gchar * prog, gboolean show);
+gboolean anjuta_util_prog_is_installed (const gchar * prog, gboolean show);
 
 gchar* anjuta_util_get_a_tmp_file (void);
 
@@ -84,6 +85,7 @@ void anjuta_util_glist_strings_free(GList* list);
 void anjuta_util_glist_strings_prefix (GList * list, const gchar *prefix);
 void anjuta_util_glist_strings_sufix (GList * list, const gchar *sufix);
 GList* anjuta_util_glist_strings_sort (GList * list);
+gchar* anjuta_util_glist_strings_join (GList * list, gchar *delimiter);
 
 /**********************************************************/
 /* Both the returned glist and the data should be g_freed */
@@ -103,6 +105,7 @@ GList * anjuta_util_update_string_list (GList *p_list, const gchar *p_str,
 										gint length);
 
 gboolean anjuta_util_create_dir (const gchar * d);
+char * anjuta_util_user_shell (void);
 pid_t anjuta_util_execute_shell (const gchar *dir, const gchar *command);
 
 gchar* anjuta_util_escape_quotes(const gchar* str);
@@ -110,8 +113,25 @@ gchar* anjuta_util_escape_quotes(const gchar* str);
 gboolean anjuta_util_path_has_extension (const gchar *path, const gchar *ext);
 gchar* anjuta_util_get_real_path (const gchar *path);
 
+gchar* anjuta_util_uri_get_dirname (const gchar *uri);
+gchar* anjuta_util_replace_home_dir_with_tilde (const gchar *uri);
+gchar* anjuta_util_str_middle_truncate (const gchar *string,
+										 guint        truncate_length);
+
 gchar* anjuta_util_get_uri_mime_type (const gchar *uri);
 
+void anjuta_util_help_display (GtkWindow   *parent,
+							   const gchar *doc_id,
+							   const gchar *file_name);
+
+/* XDG BaseDir specifcation functions */
+GFile* anjuta_util_get_user_data_file (const gchar* path, ...);
+GFile* anjuta_util_get_user_cache_file (const gchar* path, ...);
+GFile* anjuta_util_get_user_config_file (const gchar* path, ...);
+gchar* anjuta_util_get_user_data_file_path (const gchar* path, ...);
+gchar* anjuta_util_get_user_cache_file_path (const gchar* path, ...);
+gchar* anjuta_util_get_user_config_file_path (const gchar* path, ...);
+
 /* Temporarily copied here */
 
 #define ANJUTA_TYPE_BEGIN(class_name, prefix, parent_type) \
