@@ -38,7 +38,7 @@
 /*#define DEBUG*/
 #include <libanjuta/anjuta-debug.h>
 
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 
 #include <stdlib.h>
 #include <string.h>
@@ -95,7 +95,9 @@ struct _DmaVariablePacket {
 struct _DmaVariableData {
 	guchar modified;    /* Set by tree update */
 	guchar changed;     /* Set by global update */
-	gboolean analyzed;	/* Used as a tag to find variable outside scope */
+
+	gboolean exited;	/* variable outside scope */
+	gboolean deleted;	/* variable should be deleted */
 	
 	gboolean auto_update;
 	
@@ -169,7 +171,6 @@ dma_variable_data_new(const gchar *const name, gboolean auto_update)
 	}
 
 	data->changed = TRUE;
-	data->analyzed = TRUE;
 	data->auto_update = auto_update;
 		
 	return data;
@@ -346,7 +347,7 @@ delete_parent(GtkTreeModel *model, GtkTreePath* path,
 
 
 static gboolean
-clear_analyzed(GtkTreeModel *model, GtkTreePath* path,
+set_deleted(GtkTreeModel *model, GtkTreePath* path,
 				 GtkTreeIter* iter, gpointer user_data)
 {
 	DmaVariableData *data;
@@ -356,8 +357,8 @@ clear_analyzed(GtkTreeModel *model, GtkTreePath* path,
 	
 	gtk_tree_model_get(model, iter, DTREE_ENTRY_COLUMN, &data, -1);
 	g_return_val_if_fail (data, TRUE);	/* Use on root node only, data != NULL */
-					 
-	data->analyzed = FALSE;
+
+	data->deleted= TRUE;
 
 	return FALSE;	
 }
@@ -422,7 +423,8 @@ debug_tree_add_children (DebugTree *tree, GtkTreeIter* parent, const GList *chil
 					   TYPE_COLUMN, var->type == NULL ? UNKNOWN_TYPE : var->type,
 					   VALUE_COLUMN, var->value == NULL ? UNKNOWN_VALUE : var->value,
 					   VARIABLE_COLUMN, var->expression,
-					   ROOT_COLUMN, FALSE, -1);
+					   ROOT_COLUMN, FALSE,
+					   DTREE_ENTRY_COLUMN, NULL,-1);
 				data = NULL;
 			}
 			else
@@ -470,7 +472,7 @@ debug_tree_add_children (DebugTree *tree, GtkTreeIter* parent, const GList *chil
 }
 
 static void
-destroy_non_analyzed (DebugTree *tree, GtkTreeModel* model)
+destroy_deleted (DebugTree *tree, GtkTreeModel* model)
 {
 	DmaVariableData *data;
 	GtkTreeIter iter;
@@ -481,7 +483,7 @@ destroy_non_analyzed (DebugTree *tree, GtkTreeModel* model)
 	for (success = gtk_tree_model_get_iter_first (model, &iter); success == TRUE; )
 	{
 		gtk_tree_model_get(model, &iter, DTREE_ENTRY_COLUMN, &data, -1);
-		if ((data != NULL) && (data->analyzed == FALSE))
+		if ((data != NULL) && (data->deleted == TRUE))
 		{
 			success = debug_tree_remove (tree, &iter);
 		}
@@ -576,7 +578,6 @@ gdb_var_create (IAnjutaDebuggerVariableObject *variable, gpointer user_data, GEr
 	{
 		data->name = strdup (variable->name);
 	}
-    data->analyzed = TRUE;
     data->changed = TRUE;
 	
 	gtk_tree_store_set(GTK_TREE_STORE(pack->model), &iter,
@@ -636,7 +637,7 @@ on_treeview_row_expanded       (GtkTreeView     *treeview,
 									 
 	gtk_tree_model_get (model, iter, DTREE_ENTRY_COLUMN, &data, -1);
 
-	if ((data != NULL) && (data->name != NULL))
+	if ((data != NULL) && (data->name != NULL) && (tree->debugger != NULL))
 	{
 		DmaVariablePacket *pack;
 					
@@ -647,10 +648,6 @@ on_treeview_row_expanded       (GtkTreeView     *treeview,
 						(IAnjutaDebuggerCallback)gdb_var_list_children,
 						pack);
 	}
-	else
-	{
-		DEBUG_PRINT("Unexpected expand on undefined variable");
-	}
 								 
 	return;
 }
@@ -672,7 +669,7 @@ on_debug_tree_variable_changed (GtkCellRendererText *cell,
 		
 		if ((text != NULL) && (*text != '\0'))
 		{
-		    IAnjutaDebuggerVariableObject var = {NULL, NULL, NULL, NULL, FALSE, -1};
+		    IAnjutaDebuggerVariableObject var = {NULL, NULL, NULL, NULL, FALSE, FALSE, FALSE, -1};
 			
 			var.expression = text;
 			debug_tree_add_watch (tree, &var, TRUE);
@@ -698,7 +695,7 @@ on_debug_tree_value_changed (GtkCellRendererText *cell,
 		DmaVariablePacket *tran;
 
 		gtk_tree_model_get (model, &iter, DTREE_ENTRY_COLUMN, &item, -1);
-		if (item != NULL)
+		if ((item != NULL) && (item->name != NULL) && (tree->debugger != NULL))
 		{
 			/* Variable is valid */
 			dma_queue_assign_variable (tree->debugger, item->name, text);
@@ -865,12 +862,16 @@ debug_tree_find_expression (const GtkTreeModel *model, GtkTreeIter *iter, const
 	{
 		gchar *exp;
 		gchar *typ;
+		DmaVariableData *node;
 		gboolean found;
 		
-        gtk_tree_model_get (GTK_TREE_MODEL (model), iter, TYPE_COLUMN, &typ, VARIABLE_COLUMN, &exp, -1);
+        gtk_tree_model_get (GTK_TREE_MODEL (model), iter, TYPE_COLUMN, &typ,
+							VARIABLE_COLUMN, &exp,
+							DTREE_ENTRY_COLUMN, &node, -1);
 
 		found = ((type == NULL) || (strcmp (typ, type) == 0))
-			&& ((expression == NULL) || (strcmp (exp, expression) == 0));
+			&& ((expression == NULL) || (strcmp (exp, expression) == 0))
+			&& (node->exited == FALSE);
 		if (typ != NULL) g_free (typ);
 		if (exp != NULL) g_free (exp);
 		
@@ -886,16 +887,15 @@ on_replace_watch (gpointer data, gpointer user_data)
 	DebugTree* tree = (DebugTree *)user_data;
 	const gchar *expression = (const gchar *)data;
 	GtkTreeModel*const model = gtk_tree_view_get_model (GTK_TREE_VIEW(tree->view));
-	IAnjutaDebuggerVariableObject var = {NULL, NULL, NULL, NULL, FALSE, -1};
+	IAnjutaDebuggerVariableObject var = {NULL, NULL, NULL, NULL, FALSE, FALSE, FALSE, -1};
 	GtkTreeIter iter;
 
 	if (debug_tree_find_expression (model, &iter, expression, NULL))
 	{
 		DmaVariableData *data;
 
-        gtk_tree_model_get (model, &iter, DTREE_ENTRY_COLUMN, &data, -1);
-
-		if (data != NULL) data->analyzed = TRUE;
+        	gtk_tree_model_get (model, &iter, DTREE_ENTRY_COLUMN, &data, -1);
+		if (data != NULL) data->deleted = FALSE;
 	}
 	else
 	{
@@ -908,13 +908,13 @@ void
 debug_tree_replace_list (DebugTree *tree, const GList *expressions)
 {
 	GtkTreeModel* model = gtk_tree_view_get_model (GTK_TREE_VIEW(tree->view));
-		
-	/* Mark variables as not analyzed */
-	my_gtk_tree_model_foreach_child(model, NULL, clear_analyzed, NULL);	
+	
+	/* Mark variables as deleted */
+	my_gtk_tree_model_foreach_child(model, NULL, set_deleted, NULL);	
 
 	g_list_foreach ((GList *)expressions, on_replace_watch, tree);	
 
-	destroy_non_analyzed (tree, model);	
+	destroy_deleted (tree, model);	
 }
 
 void
@@ -1007,7 +1007,7 @@ on_add_watch (gpointer data, gpointer user_data)
 {
 	DebugTree* this = (DebugTree *)user_data;
 	gboolean auto_update = ((const gchar *)data)[0] & AUTO_UPDATE_WATCH ? TRUE : FALSE;
-	IAnjutaDebuggerVariableObject var = {NULL, NULL, NULL, NULL, FALSE, -1};
+	IAnjutaDebuggerVariableObject var = {NULL, NULL, NULL, NULL, FALSE, FALSE, FALSE, -1};
 
 	var.expression = &((gchar *)data)[1];
 	debug_tree_add_watch (this, &var, auto_update);
@@ -1023,7 +1023,7 @@ static void
 on_add_manual_watch (gpointer data, gpointer user_data)
 {
 	DebugTree* this = (DebugTree *)user_data;
-	IAnjutaDebuggerVariableObject var = {NULL, NULL, NULL, NULL, FALSE, -1};
+	IAnjutaDebuggerVariableObject var = {NULL, NULL, NULL, NULL, FALSE, FALSE, FALSE, -1};
 
 	var.expression = &((gchar *)data)[0];
 	debug_tree_add_watch (this, &var, FALSE);
@@ -1033,7 +1033,7 @@ static void
 on_add_auto_watch (gpointer data, gpointer user_data)
 {
 	DebugTree* this = (DebugTree *)user_data;
-	IAnjutaDebuggerVariableObject var = {NULL, NULL, NULL, NULL, FALSE, -1};
+	IAnjutaDebuggerVariableObject var = {NULL, NULL, NULL, NULL, FALSE, FALSE, -1};
 	
 	var.expression = &((gchar *)data)[0];
 	debug_tree_add_watch (this, &var, TRUE);
@@ -1067,7 +1067,12 @@ on_debug_tree_changed (gpointer data, gpointer user_data)
 				DmaVariableData *data;
 				gtk_tree_model_get (model, &iter, DTREE_ENTRY_COLUMN, &data, -1);
 		
-				if (data != NULL) data->changed = TRUE;
+				if (data != NULL)
+				{	
+					data->changed = var->changed;
+					data->exited = var->exited;
+					data->deleted = var->deleted;
+				}
 				
 				return;
 			}
@@ -1095,6 +1100,80 @@ on_debug_tree_modified (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *ite
 	return FALSE;
 }
 
+static gboolean
+debug_tree_update_real (DebugTree* tree, GtkTreeIter* iter, gboolean force)
+{
+	GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (tree->view));
+	DmaVariableData *data = NULL;
+	GtkTreeIter child;
+	gboolean search;
+	gboolean refresh = TRUE;
+
+	gtk_tree_model_get (model, iter, DTREE_ENTRY_COLUMN, &data, -1);
+	if (data == NULL) return FALSE;
+
+	if (data->name == NULL)
+	{
+		/* Check is the variable creation is not pending */
+		if (data->packet == NULL)
+		{
+			/* Variable need to be created first */
+			gchar *exp;
+			DmaVariablePacket *pack;
+		
+			gtk_tree_model_get (model, iter, VARIABLE_COLUMN, &exp, -1);
+			pack = dma_variable_packet_new(model, iter, tree, data);
+			data->modified = TRUE;
+			dma_queue_create_variable (
+					tree->debugger,
+					exp,
+					(IAnjutaDebuggerCallback)gdb_var_create,
+					pack);
+			g_free (exp);
+		}
+		
+		return FALSE;
+	}	
+	else if (force || (data->auto_update && data->changed))
+	{
+		DmaVariablePacket *pack = dma_variable_packet_new(model, iter, tree, data);
+		refresh = data->modified != (data->changed != FALSE);
+		data->modified = (data->changed != FALSE);
+		dma_queue_evaluate_variable (
+				tree->debugger,
+				data->name,
+				(IAnjutaDebuggerCallback)gdb_var_evaluate_expression,
+				pack);
+	}
+	else
+	{
+		refresh = data->modified;
+		data->modified = FALSE;
+	}
+	
+	/* update children */
+	for (search = gtk_tree_model_iter_children(model, &child, iter);
+		search == TRUE;
+	    search = gtk_tree_model_iter_next (model, &child))
+	{
+		if (debug_tree_update_real (tree, &child, force))
+		{
+			refresh = data->modified == TRUE;
+			data->modified = TRUE;
+		}
+	}
+
+	if (refresh)
+	{
+		GtkTreePath *path;
+		path = gtk_tree_model_get_path (model, iter);
+		gtk_tree_model_row_changed (model, path, iter);
+		gtk_tree_path_free (path);
+	}
+	
+	return data->modified;
+}
+
 static void
 on_debug_tree_update_all (const GList *change, gpointer user_data, GError* err)
 {
@@ -1117,7 +1196,7 @@ on_debug_tree_update_all (const GList *change, gpointer user_data, GError* err)
 			
 			gtk_tree_model_get (model, &iter, DTREE_ENTRY_COLUMN, &data, -1);
 	
-			debug_tree_update (tree, &iter, FALSE);
+			debug_tree_update_real (tree, &iter, FALSE);
 		} while (gtk_tree_model_iter_next (model, &iter) == TRUE);
 	}
 	
@@ -1205,71 +1284,14 @@ debug_tree_remove (DebugTree *tree, GtkTreeIter* iter)
 gboolean
 debug_tree_update (DebugTree* tree, GtkTreeIter* iter, gboolean force)
 {
-	GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (tree->view));
-	DmaVariableData *data = NULL;
-	GtkTreeIter child;
-	gboolean search;
-	gboolean refresh = TRUE;
-	
-	gtk_tree_model_get (model, iter, DTREE_ENTRY_COLUMN, &data, -1);
-	if (data == NULL) return FALSE;
-
-	if (data->name == NULL)
+	if (tree->debugger != NULL)
 	{
-		/* Variable need to be created first */
-		gchar *exp;
-		DmaVariablePacket *pack;
-			
-		gtk_tree_model_get (model, iter, VARIABLE_COLUMN, &exp, -1);
-		pack = dma_variable_packet_new(model, iter, tree, data);
-		data->modified = TRUE;
-		dma_queue_create_variable (
-				tree->debugger,
-				exp,
-				(IAnjutaDebuggerCallback)gdb_var_create,
-				pack);
-		g_free (exp);
-		
-		return FALSE;
-	}	
-	else if (force || (data->auto_update && data->changed))
-	{
-		DmaVariablePacket *pack = dma_variable_packet_new(model, iter, tree, data);
-		refresh = data->modified != (data->changed != FALSE);
-		data->modified = (data->changed != FALSE);
-		dma_queue_evaluate_variable (
-				tree->debugger,
-				data->name,
-				(IAnjutaDebuggerCallback)gdb_var_evaluate_expression,
-				pack);
+		return debug_tree_update_real (tree, iter, force);
 	}
 	else
 	{
-		refresh = data->modified;
-		data->modified = FALSE;
+		return FALSE;
 	}
-	
-	/* update children */
-	for (search = gtk_tree_model_iter_children(model, &child, iter);
-		search == TRUE;
-	    search = gtk_tree_model_iter_next (model, &child))
-	{
-		if (debug_tree_update (tree, &child, force))
-		{
-			refresh = data->modified == TRUE;
-			data->modified = TRUE;
-		}
-	}
-
-	if (refresh)
-	{
-		GtkTreePath *path;
-		path = gtk_tree_model_get_path (model, iter);
-		gtk_tree_model_row_changed (model, path, iter);
-		gtk_tree_path_free (path);
-	}
-	
-	return data->modified;
 }
 
 void
@@ -1454,7 +1476,6 @@ void
 debug_tree_free (DebugTree * tree)
 {
 	GtkTreeModel *model;
-	// AnjutaUI *ui;
 	
 	g_return_if_fail (tree);
 
