@@ -25,7 +25,6 @@
 #include "patch-plugin.h"
 
 #define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-patch.ui"
-#define ICON_FILE_48 "anjuta-patch-plugin-48.png"
 
 static gpointer parent_class;
 
@@ -85,7 +84,7 @@ patch_plugin_activate (AnjutaPlugin *plugin)
 	
 	/* Register icon */
 	BEGIN_REGISTER_ICON (plugin);
-	REGISTER_ICON (ICON_FILE_48, "patch-plugin-icon");
+	REGISTER_ICON (ICON_FILE, "patch-plugin-icon");
 	END_REGISTER_ICON;
 
 
@@ -122,14 +121,14 @@ patch_plugin_finalize (GObject *obj)
 	PatchPlugin *p_plugin;
 	p_plugin = ANJUTA_PLUGIN_PATCH (obj);
 	/*/
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (obj));
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 
 static void
 patch_plugin_dispose (GObject *obj)
 {
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (obj));
+	G_OBJECT_CLASS (parent_class)->dispose (obj);
 }
 
 
