@@ -38,6 +38,7 @@
 #include <bonobo/bonobo-dock-item.h>
 
 #include <libanjuta/anjuta-shell.h>
+#include <libanjuta/anjuta-ui.h>
 #include <libanjuta/anjuta-utils.h>
 #include <libanjuta/resources.h>
 #include <libanjuta/anjuta-plugin-manager.h>
@@ -106,52 +107,6 @@ on_toolbar_style_changed (GConfClient* client, guint id, GConfEntry* entry,
 		}
 	}
 }
-	
-
-/*
- * Accels
- */
-static gchar *
-get_accel_file (void)
-{
-	gchar *anjuta_dir = NULL;
-	gchar *filename = NULL;
-
-	anjuta_dir = anjuta_util_get_user_config_dir ();
-
-	if (anjuta_dir != NULL)
-		filename = g_build_filename (anjuta_dir, "anjuta-accels", NULL);
-	
-	g_free (anjuta_dir);
-
-	return filename;
-}
-
-static void
-load_accels (void)
-{
-	gchar *filename;
-
-	filename = get_accel_file ();
-	if (filename != NULL)
-	{
-		gtk_accel_map_load (filename);
-		g_free (filename);
-	}
-}
-
-static void
-save_accels (void)
-{
-	gchar *filename;
-
-	filename = get_accel_file ();
-	if (filename != NULL)
-	{
-		gtk_accel_map_save (filename);
-		g_free (filename);
-	}
-}
 
 static void
 on_gdl_style_changed (GConfClient* client, guint id, GConfEntry* entry,
@@ -249,22 +204,6 @@ on_layout_locked_notify (GdlDockMaster *master, GParamSpec *pspec,
 								  (locked == 1));
 }
 
-static void
-layout_changed (GtkWidget *w, AnjutaApp *app)
-{
-	BonoboDockLayout *layout;
-	gchar *s;
-	
-	g_return_if_fail (ANJUTA_IS_APP (app));
-	g_return_if_fail (BONOBO_IS_DOCK (w));
-
-	layout = bonobo_dock_get_layout (BONOBO_DOCK (app->bonobo_dock));
-	s = bonobo_dock_layout_create_string (layout);
-	anjuta_preferences_set (app->preferences, "anjuta.bonobo.layout", s);
-	g_object_unref (G_OBJECT (layout));
-	g_free (s);
-}
-
 static void
 anjuta_app_add_dock_item (AnjutaApp *app, BonoboDockItem *item,
 						  BonoboDockPlacement placement, gint band_num,
@@ -389,14 +328,12 @@ on_add_merge_widget (GtkUIManager *merge, GtkWidget *widget,
 		offset_key = g_strconcat (toolbarname, ".offset", NULL);		
 		band = anjuta_preferences_get_int_with_default(pr, band_key, -1);
 		position = anjuta_preferences_get_int_with_default(pr, position_key, 0);
-		offset = anjuta_preferences_get_int_with_default(pr, offset_key, 0);		
-		/* Without these check you might see odd results */
-		if (band < 1)
-			band = count + 1;
+		offset = anjuta_preferences_get_int_with_default(pr, offset_key, 0);
 		g_object_set_data(G_OBJECT(widget), "position", GINT_TO_POINTER(position));
 		g_object_set_data(G_OBJECT(widget), "offset", GINT_TO_POINTER(offset));
 		g_object_set_data (G_OBJECT (widget), "band",
 						   GINT_TO_POINTER(band));
+		
 		g_free(offset_key);
 		g_free(position_key);
 		g_free(band_key);
@@ -659,7 +596,6 @@ anjuta_app_instance_init (AnjutaApp *app)
 	GtkWidget *dockbar;
 	GtkAction* action;
 	GList *plugins_dirs = NULL;
-	gchar *bonobo_string = NULL;
 	GdkGeometry size_hints = {
     	100, 100, 0, 0, 100, 100, 1, 1, 0.0, 0.0, GDK_GRAVITY_NORTH_WEST
   	};
@@ -701,7 +637,6 @@ anjuta_app_instance_init (AnjutaApp *app)
 	dockbar = gdl_dock_bar_new (GDL_DOCK(app->dock));
 	gtk_widget_show (dockbar);
 	gtk_box_pack_start(GTK_BOX (hbox), dockbar, FALSE, FALSE, 0);
-	gtk_box_pack_end (GTK_BOX (main_box), hbox, TRUE, TRUE, 0);
 	
 	app->layout_manager = gdl_dock_layout_new (GDL_DOCK (app->dock));
 	g_signal_connect (app->layout_manager, "notify::dirty",
@@ -767,18 +702,7 @@ anjuta_app_instance_init (AnjutaApp *app)
 	app->bonobo_dock = bonobo_dock_new ();
 	gtk_widget_show (app->bonobo_dock);
 	
-	g_signal_connect (app->bonobo_dock, "layout_changed",
-					  G_CALLBACK (layout_changed), app);
-	
-	app->bonobo_layout = bonobo_dock_layout_new ();
-	
-	bonobo_string = anjuta_preferences_get (app->preferences, "anjuta.bonobo.layout");
-	if (bonobo_string)
-	{
-		bonobo_dock_layout_parse_string (app->bonobo_layout, bonobo_string);
-		g_free (bonobo_string);
-	}
-			    
+	app->bonobo_layout = bonobo_dock_layout_new ();   
 	bonobo_dock_add_from_layout (BONOBO_DOCK (app->bonobo_dock),
 								 app->bonobo_layout);
 						    
@@ -802,7 +726,8 @@ anjuta_app_instance_init (AnjutaApp *app)
 	 * We have to add the dock after merging the ui
 	 */
 	gtk_box_pack_start (GTK_BOX (main_box), app->bonobo_dock,
-			    FALSE, FALSE, 0);
+			    TRUE, TRUE, 0);
+	bonobo_dock_set_client_area (BONOBO_DOCK (app->bonobo_dock), hbox);
 	
 	/* create toolbar menus */
 	toolbar_menu =
@@ -840,7 +765,7 @@ anjuta_app_instance_init (AnjutaApp *app)
 					  G_CALLBACK (on_session_load), app);
 	
 	/* Loading accels */
-	load_accels ();
+	anjuta_ui_load_accels ();
 }
 
 static void
@@ -944,7 +869,7 @@ anjuta_app_layout_save (AnjutaApp *app, const gchar *filename,
 		g_warning ("Saving dock layout to '%s' failed!", filename);
 		
 	/* This is a good place to save the accels too */
-	save_accels ();
+	anjuta_ui_save_accels ();
 }
 
 static void
